@@ -10,11 +10,9 @@ import subprocess
 import yaml
 
 def start_interpreter(**variables):
-    class ShopifyAPI(code.InteractiveConsole):
-        pass
-
+    console = type('shopify ' + shopify.version.VERSION, (code.InteractiveConsole, object), {})
     import readline
-    ShopifyAPI(variables).interact()
+    console(variables).interact()
 
 class ConfigFileError(StandardError):
     pass
@@ -192,6 +190,12 @@ class Tasks(object):
 
         start_interpreter(shopify=shopify)
 
+    @classmethod
+    @usage("version")
+    def version(cls, connection=None):
+        """output the shopify library version"""
+        print(shopify.version.VERSION)
+
     @classmethod
     def _available_connections(cls):
         return map(lambda item: os.path.splitext(os.path.basename(item))[0],
