@@ -26,7 +26,6 @@ class ShopifyResourceMeta(ResourceMeta):
     @property
     def connection(cls):
         """HTTP connection for the current thread"""
-        super_class = cls.__mro__[1]
         local = cls._threadlocal
         if not getattr(local, 'connection', None):
             # Make sure these variables are no longer affected by other threads.
@@ -34,6 +33,10 @@ class ShopifyResourceMeta(ResourceMeta):
             local.password = cls.password
             local.site = cls.site
             local.timeout = cls.timeout
+            local.headers = cls.headers
+            local.format = cls.format
+            if cls.site is None:
+                raise ValueError("No shopify session is active")
             local.connection = ShopifyConnection(
                 cls.site, cls.user, cls.password, cls.timeout, cls.format)
         return local.connection
@@ -87,6 +90,27 @@ class ShopifyResourceMeta(ResourceMeta):
     timeout = property(get_timeout, set_timeout, None,
                        'Socket timeout for HTTP requests')
 
+    def get_headers(cls):
+        if not hasattr(cls._threadlocal, 'headers'):
+            cls._threadlocal.headers = ShopifyResource._headers
+        return cls._threadlocal.headers
+
+    def set_headers(cls, value):
+        cls._threadlocal.headers = value
+
+    headers = property(get_headers, set_headers, None,
+                       'The headers sent with HTTP requests')
+
+    def get_format(cls):
+        return getattr(cls._threadlocal, 'format', ShopifyResource._format)
+
+    def set_format(cls, value):
+        cls._threadlocal.connection = None
+        ShopifyResource._format = cls._threadlocal.format = value
+
+    format = property(get_format, set_format, None,
+                      'Encoding used for request and responses')
+
     def get_primary_key(cls):
         return cls._primary_key
 
@@ -115,20 +139,23 @@ class ShopifyResource(ActiveResource, mixins.Countable):
         self._update(self.__class__.format.decode(response.body))
 
     def __get_id(self):
-        if self.klass.primary_key != "id":
-            return self.attributes.get(self.klass.primary_key)
-        else:
-            return super(ShopifyResource, self).id
+        return self.attributes.get(self.klass.primary_key)
 
     def __set_id(self, value):
-        if self.klass.primary_key != "id":
-            self.attributes[self.klass.primary_key] = value
-        else:
-            super(ShopifyResource, self).id = value
+        self.attributes[self.klass.primary_key] = value
 
     id = property(__get_id, __set_id, None, 'Value stored in the primary key')
 
     def save(self):
-        # See pyactiveresource issue 14: http://code.google.com/p/pyactiveresource/issues/detail?id=14
-        self.errors.clear()
+        self.errors.clear() # Bug in pyactiveresource v1.0.1, but fixed in trunk at revision 96
         return super(ShopifyResource, self).save()
+
+    @classmethod
+    def activate_session(cls, session):
+        cls.site = session.site
+
+    @classmethod
+    def clear_session(cls):
+        cls.site = None
+        cls.user = None
+        cls.password = None
